==> goods-center-api-2.4.10-20180610.034104-1-sources.jar: cn/com/duiba/goods/center/api/remoteservice/dto/couponcode/CouponCodeOperationLogDto.java <==
package cn.com.duiba.goods.center.api.remoteservice.dto.couponcode;

import java.io.Serializable;
import java.util.Date;

public class CouponCodeOperationLogDto implements Serializable
{
	private static final long serialVersionUID = -2679028086556315596L;
	private String operationName;
	private String remarks;
	private Integer operationTotal;
	private String fileUrl;
	private Integer operationType;

	private Long couponCodeBatchId;
	private Long couponCodeBaseId;

	public Long getCouponCodeBatchId()
	{
		return couponCodeBatchId;
	}

	public void setCouponCodeBatchId(Long couponCodeBatchId)
	{
		this.couponCodeBatchId = couponCodeBatchId;
	}

	public Long getCouponCodeBaseId()
	{
		return couponCodeBaseId;
	}

	public void setCouponCodeBaseId(Long couponCodeBaseId)
	{
		this.couponCodeBaseId = couponCodeBaseId;
	}

	public String getOperationName()
	{
		return operationName;
	}

	public void setOperationName(String operationName)
	{
		this.operationName = operationName;
	}

	public String getRemarks()
	{
		return remarks;
	}

	public void setRemarks(String remarks)
	{
		this.remarks = remarks;
	}

	public Integer getOperationTotal()
	{
		return operationTotal;
	}

	public void setOperationTotal(Integer operationTotal)
	{
		this.operationTotal = operationTotal;
	}

	public String getFileUrl()
	{
		return fileUrl;
	}

	public void setFileUrl(String fileUrl)
	{
		this.fileUrl = fileUrl;
	}

	public Integer getOperationType()
	{
		return operationType;
	}

	public void setOperationType(Integer operationType)
	{
		this.operationType = operationType;
	}

	private Long id;
	private Date gmtCreate;
	private Date gmtModified;

	public Long getId()
	{
		return id;
	}

	public void setId(Long id)
	{
		this.id = id;
	}

	public Date getGmtCreate()
	{
		return gmtCreate;
	}

	public void setGmtCreate(Date gmtCreate)
	{
		this.gmtCreate = gmtCreate;
	}

	public Date getGmtModified()
	{
		return gmtModified;
	}

	public void setGmtModified(Date gmtModified)
	{
		this.gmtModified = gmtModified;
	}
}

==> goods-center-api-2.11.13-20230509.070934-3-sources.jar: cn/com/duiba/goods/center/api/remoteservice/dto/couponcode/CouponCodeOperationLogDto.java <==
package cn.com.duiba.goods.center.api.remoteservice.dto.couponcode;

import java.io.Serializable;
import java.util.Date;

public class CouponCodeOperationLogDto implements Serializable
{
	private static final long serialVersionUID = -2679028086556315596L;
	private String operationName;
	private String remarks;
	private Integer operationTotal;
	private String fileUrl;
	private Integer operationType;

	private Long couponCodeBatchId;
	private Long couponCodeBaseId;

	//日志来源，0:券码库；1:卡券库'
	private Integer logSource;

	public Long getCouponCodeBatchId()
	{
		return couponCodeBatchId;
	}

	public void setCouponCodeBatchId(Long couponCodeBatchId)
	{
		this.couponCodeBatchId = couponCodeBatchId;
	}

	public Long getCouponCodeBaseId()
	{
		return couponCodeBaseId;
	}

	public void setCouponCodeBaseId(Long couponCodeBaseId)
	{
		this.couponCodeBaseId = couponCodeBaseId;
	}

	public String getOperationName()
	{
		return operationName;
	}

	public void setOperationName(String operationName)
	{
		this.operationName = operationName;
	}

	public String getRemarks()
	{
		return remarks;
	}

	public void setRemarks(String remarks)
	{
		this.remarks = remarks;
	}

	public Integer getOperationTotal()
	{
		return operationTotal;
	}

	public void setOperationTotal(Integer operationTotal)
	{
		this.operationTotal = operationTotal;
	}

	public String getFileUrl()
	{
		return fileUrl;
	}

	public void setFileUrl(String fileUrl)
	{
		this.fileUrl = fileUrl;
	}

	public Integer getOperationType()
	{
		return operationType;
	}

	public void setOperationType(Integer operationType)
	{
		this.operationType = operationType;
	}

	private Long id;
	private Date gmtCreate;
	private Date gmtModified;

	public Long getId()
	{
		return id;
	}

	public void setId(Long id)
	{
		this.id = id;
	}

	public Date getGmtCreate()
	{
		return gmtCreate;
	}

	public void setGmtCreate(Date gmtCreate)
	{
		this.gmtCreate = gmtCreate;
	}

	public Date getGmtModified()
	{
		return gmtModified;
	}

	public void setGmtModified(Date gmtModified)
	{
		this.gmtModified = gmtModified;
	}

	public Integer getLogSource() {
		return logSource;
	}

	public void setLogSource(Integer logSource) {
		this.logSource = logSource;
	}
}
